API_PATH_DEFAULT_PREFIX = "/api"
API_ROUTE_NAME_PREFIX = "cube_api_v1_"

DEFAULT_ROUTE_PARAMS = {
    "request_method": "POST",
    "renderer": "json",
    "require_csrf": False,
    "openapi": True,
}
